@@ -18,9 +18,11 @@ import pbr.version
 
 from os_client_config import cloud_config
 from os_client_config.config import OpenStackConfig  # noqa
+from os_client_config import vendors  # noqa
 
 
 __version__ = pbr.version.VersionInfo('os_client_config').version_string()
+_config = None
 
 
 def get_config(
@@ -28,21 +30,23 @@ def get_config(
         app_name=None, app_version=None,
         **kwargs):
     load_yaml_config = kwargs.pop('load_yaml_config', True)
-    config = OpenStackConfig(
-        load_yaml_config=load_yaml_config,
-        app_name=app_name, app_version=app_version)
+    global _config
+    if not _config:
+        _config = OpenStackConfig(
+            load_yaml_config=load_yaml_config,
+            app_name=app_name, app_version=app_version)
     if options:
-        config.register_argparse_arguments(options, sys.argv, service_key)
+        _config.register_argparse_arguments(options, sys.argv, service_key)
         parsed_options = options.parse_known_args(sys.argv)
     else:
         parsed_options = None
 
-    return config.get_one_cloud(options=parsed_options, **kwargs)
+    return _config.get_one_cloud(options=parsed_options, **kwargs)
 
 
 def make_rest_client(
         service_key, options=None,
-        app_name=None, app_version=None,
+        app_name=None, app_version=None, version=None,
         **kwargs):
     """Simple wrapper function. It has almost no features.
 
@@ -60,7 +64,7 @@ def make_rest_client(
         service_key=service_key, options=options,
         app_name=app_name, app_version=app_version,
         **kwargs)
-    return cloud.get_session_client(service_key)
+    return cloud.get_session_client(service_key, version=version)
 # Backwards compat - simple_client was a terrible name
 simple_client = make_rest_client
 # Backwards compat - session_client was a terrible name
